<?php

namespace Drupal\commerce_eta\Controller;

use Drupal\commerce_eta\Entity\Trigger;
use Drupal\commerce_eta\Event\OrderEvent;
use Drupal\commerce_eta\EventLogItem;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Entity\EntityInterface;

/**
 * Class EventDispatchController.
 */
class EventDispatchController extends ControllerBase {

  /**
   * The event dispatcher service.
   *
   * @var \Symfony\Component\EventDispatcher\EventDispatcherInterface
   */
  protected $event_dispatcher;

  /**
   * @var \Psr\Log\LoggerInterface
   */
  protected $logger;

  /**
   * @var \Drupal\commerce_eta\Entity\Trigger
   */
  protected $trigger;

  /**
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * @var array
   */
  protected $entity_ids = [];

  /**
   * @var integer
   */
  protected $run_count;

  public function __construct(Trigger $trigger) {

    $this->trigger = $trigger;

    $this->event_dispatcher = \Drupal::service('event_dispatcher');

    $this->logger = \Drupal::logger('commerce_eta');

    $this->database = \Drupal::database();

    switch ($trigger->getTargetEntityType()) {
      case 'commerce_order':
        //$orders = \Drupal\commerce_order\Entity\Order::loadMultiple();
        $query = \Drupal::entityQuery($this->trigger->getTargetEntityType());
        $order_ids = $query->execute();

        foreach($order_ids as $order_id) {
          $order = \Drupal\commerce_order\Entity\Order::load($order_id);
          if($trigger->applies($order)) {
            $this->entity_ids[$order_id] = $order_id;
          }
        }

        break;

      // TOO DOO: ADD MORE COMMERCE ENTITIES HERE.
      default:
        return;
    }


    // Run Limiter
    if(!empty($this->trigger->getRunLimit())) {
      $this->runLimiter();
    }


  }

  private function runLimiter() {
    foreach($this->entity_ids as $entity_id) {
      if($this->trigger->getRunLimit() <= $this->getRunCount($entity_id)) {
        unset($this->entity_ids[$entity_id]);
      }
    }
  }

  /**
   * Fire.
   *
   * @return string
   *   Return Hello string.
   */
  public function fire() {
    if($this->trigger->getStatus() && !empty($this->entity_ids)) {
      switch ($this->trigger->getTargetEntityType()) {
        case 'commerce_order':
          foreach($this->entity_ids as $entity_id) {
            /** @var \Drupal\commerce_order\Entity\Order $entity */
            $order = \Drupal\commerce_order\Entity\Order::load($entity_id);
            // Log this event if logging is enabled for this trigger.
            if($this->trigger->getLogStatus()) {
              $this->logger->info($this->trigger->label() . ' has attempted to fire an event for order ID ' . $order->id());
            }

            // Add the event to the DB as having fired.
            $this->dbInsertEvent($order);

            // Create and fire the event
            // Run count should be run again to reflect THIS event's run count, not the previous run count. So it needs to be run after the last DB insert.
            $event = new OrderEvent($this->trigger, $order, $this->getRunCount($order->id()));
            $response = $this->event_dispatcher->dispatch(OrderEvent::COMMERCE_ETA_ORDER, $event);
          }
          // Return a boolean stating that the events have fired.
          return TRUE;
          break;
        default:
          // Return a boolean stating that no events have fired.
          return FALSE;
      }

    } else {
      // Return a boolean stating that no events have fired.
      return FALSE;
    }

  }

  private function dbInsertEvent(EntityInterface $entity) {
    $now = new DrupalDateTime('now');

    $event_log_item = new EventLogItem($this->trigger->id(), $this->trigger->getTargetEntityType(), $entity->id(), $now->getTimestamp());

    $insert_query = $this->database->insert('commerce_eta_events')->fields($event_log_item->getQueryFieldData())->execute();
  }

  public function getNextRunCount() {
    return (string)count($this->entity_ids);
  }

  public function getRunCount($entity_id) {
    $query = $this->database->query("SELECT event_id, entity_id FROM commerce_eta_events WHERE entity_id = :entity_id AND entity_type = :entity_type", [
      ':entity_id' => $entity_id,
      ':entity_type' => $this->trigger->getTargetEntityType(),
    ]);
    $result = $query->fetchAll();
    return $this->run_count = count($result);
  }
}
