<?php


namespace Drupal\commerce_eta;


use Drupal\commerce_eta\Entity\Trigger;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Entity\EntityInterface;


class EventLogItem {

  /**
   * @var string
   */
  protected $trigger_id;

  /**
   * @var string
   */
  protected $target_entity_type;

  /**
   * @var integer
   */
  protected $entity_id;

  /**
   * @var integer
   */
  protected $timestamp;

  /**
   * @var integer
   */
  protected $event_id;

  public function __construct($trigger_id, $target_entity_type, $entity_id,  $timestamp, $event_id = NULL) {
    $this->trigger_id = $trigger_id;
    $this->target_entity_type = $target_entity_type;
    $this->entity_id = $entity_id;
    $this->timestamp = $timestamp;

    if($event_id) {
      $this->event_id = $event_id;
    }

  }

  public function getTrigger() {
    $trigger = Trigger::load($this->trigger_id);
    return $trigger;
  }

  public function getTargetEntity() {
    /** @var EntityInterface $entity */
    $entity = \Drupal::entityTypeManager()->getStorage($this->target_entity_type)->load($this->entity_id);
    return $entity;
  }

  public function getDrupalDateTime() {
    $time = DrupalDateTime::createFromTimestamp($this->timestamp);
    return $time;
  }

  public function getEventId() {
    return $this->event_id;
  }

  public function getQueryFieldData() {
    return [
      'trigger_id' => $this->trigger_id,
      'entity_type' => $this->target_entity_type,
      'entity_id' => $this->entity_id,
      'timestamp' => $this->timestamp,
    ];
  }

}
