<?php

namespace Drupal\commerce_eta\Form;

use Drupal\Core\Entity\EntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Builds the form to delete Trigger entities.
 */
class TriggerDeleteForm extends EntityConfirmFormBase {

  /**
   * {@inheritdoc}
   */

  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['delete_events'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Delete all events associated with this trigger?'),
      '#default_value' => TRUE,
    ];

    return parent::buildForm($form, $form_state); // TODO: Change the autogenerated stub


  }

  public function getQuestion() {
    return $this->t('Are you sure you want to delete %name?', ['%name' => $this->entity->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.commerce_event_trigger.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\commerce_eta\Entity\Trigger $this->entity */
    // Remove all events for this trigger.
    if($form_state->getValue('delete_events')) {
      \Drupal::database()->delete('commerce_eta_events')->condition('trigger_id', $this->entity->id())->execute();
    }

    $this->entity->delete();

    $this->messenger()->addMessage(
      $this->t('content @type: deleted @label.', [
        '@type' => $this->entity->bundle(),
        '@label' => $this->entity->label(),
      ])
    );

    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
